summaryrefslogtreecommitdiff
path: root/spec/ruby/core/dir/children_spec.rb
diff options
context:
space:
mode:
Diffstat (limited to 'spec/ruby/core/dir/children_spec.rb')
-rw-r--r--spec/ruby/core/dir/children_spec.rb8
1 files changed, 4 insertions, 4 deletions
diff --git a/spec/ruby/core/dir/children_spec.rb b/spec/ruby/core/dir/children_spec.rb
index d28f1b1346..ef8b20b1f0 100644
--- a/spec/ruby/core/dir/children_spec.rb
+++ b/spec/ruby/core/dir/children_spec.rb
@@ -43,10 +43,10 @@ ruby_version_is "2.5" do
it "returns children encoded with the filesystem encoding by default" do
# This spec depends on the locale not being US-ASCII because if it is, the
# children that are not ascii_only? will be ASCII-8BIT encoded.
children = Dir.children(File.join(DirSpecs.mock_dir, 'special')).sort
encoding = Encoding.find("filesystem")
- encoding = Encoding::ASCII_8BIT if encoding == Encoding::US_ASCII
+ encoding = Encoding::BINARY if encoding == Encoding::US_ASCII
platform_is_not :windows do
children.should include("こんにちは.txt".force_encoding(encoding))
end
@@ -110,11 +110,11 @@ ruby_version_is "2.6" do
it "returns children encoded with the filesystem encoding by default" do
# This spec depends on the locale not being US-ASCII because if it is, the
# children that are not ascii_only? will be ASCII-8BIT encoded.
@dir = Dir.new(File.join(DirSpecs.mock_dir, 'special'))
children = @dir.children.sort
encoding = Encoding.find("filesystem")
- encoding = Encoding::ASCII_8BIT if encoding == Encoding::US_ASCII
+ encoding = Encoding::BINARY if encoding == Encoding::US_ASCII
platform_is_not :windows do
children.should include("こんにちは.txt".force_encoding(encoding))
end
@@ -43,10 +43,10 @@ ruby_version_is "2.5" do
it "returns children encoded with the filesystem encoding by default" do
# This spec depends on the locale not being US-ASCII because if it is, the
- # children that are not ascii_only? will be ASCII-8BIT encoded.
+ # children that are not ascii_only? will be BINARY encoded.
children = Dir.children(File.join(DirSpecs.mock_dir, 'special')).sort
encoding = Encoding.find("filesystem")
@@ -110,11 +110,11 @@ ruby_version_is "2.6" do
it "returns children encoded with the filesystem encoding by default" do
# This spec depends on the locale not being US-ASCII because if it is, the
- # children that are not ascii_only? will be ASCII-8BIT encoded.
+ # children that are not ascii_only? will be BINARY encoded.
children = @dir.children.sort